#include <memory>

//
// Created by trotfunky on 06/06/19.
//

#include "Game.h"


Game::Game(std::vector<std::string>& levels, std::vector<std::string>& textures) : levelFiles(std::move(levels)),
    textureFiles(std::move(textures))
{
    loadTextures();
}

void Game::loadLevel(int levelId)
{
    pugi::xml_document document;
    pugi::xml_parse_result result = document.load_file((pro_maat::levelFolder+levelFiles.at(levelId)).c_str());

    if(!result)
    {
//        std::cerr << "Error while loading level :\n" << "\t" << result.description() << std::endl;
//        exit(-1);
        pro_maat::errorWindow(result.description());
    }

    currentLevel = std::make_unique<Level>(document,textures);
}

void Game::loadTextures()
{
    textures.reserve(textureFiles.size());
    for(const std::string& filePath : textureFiles)
    {
        textures.emplace_back(std::make_unique<sf::Texture>());
        textures.back()->loadFromFile(pro_maat::textureFolder+filePath);
    }
}

void Game::runGame()
{
    sf::RenderWindow window(sf::VideoMode(1280,1024),"Project Maat");

    while (window.isOpen())
    {
        sf::Event event;
        while (window.pollEvent(event))
        {
            if (event.type == sf::Event::Closed)
            {
                window.close();
            }
            // FIXME : For testing purposes
            if (event.type == sf::Event::KeyPressed)
            {
                currentLevel->runStep();
            }
        }
        window.clear(sf::Color::White);
        // TODO : Consider drawing in a sf::RenderTexture to allow positioning the level at a fixed position ?
        currentLevel->render(window);
        window.display();
    }
}

Game::operator bool() const
{
    return (currentLevel ? true : false);
}
